@@ -14,6 +14,11 @@ urlpatterns = [
         magicauth_views.EmailSentView.as_view(),
         name="magicauth-email-sent",
     ),
+    path(
+        magicauth_settings.WAIT_URL,
+        magicauth_views.WaitView.as_view(),
+        name="magicauth-wait",
+    ),
     path(
         magicauth_settings.VALIDATE_TOKEN_URL,
         magicauth_views.ValidateTokenView.as_view(),
